pub struct CacheAside<S> { /* private fields */ }Expand description
High-level cache-aside client with singleflight and negative caching.
Implementations
Sourceimpl<S> CacheAside<S>
impl<S> CacheAside<S>
Sourcepub fn new(store: S, config: CacheAsideConfig) -> Self
pub fn new(store: S, config: CacheAsideConfig) -> Self
Creates a cache-aside helper around the given store.
Sourcepub fn stats(&self) -> CacheStats
pub fn stats(&self) -> CacheStats
Returns shared cache statistics.
Sourcepub fn with_metrics(self, metrics: MetricsRegistry) -> Self
pub fn with_metrics(self, metrics: MetricsRegistry) -> Self
Attaches a metrics registry to this cache-aside helper.
Sourceimpl<S> CacheAside<S>where
S: CacheStore,
impl<S> CacheAside<S>where
S: CacheStore,
Sourcepub async fn delete(&self, key: &CacheKey) -> CacheResult<()>
pub async fn delete(&self, key: &CacheKey) -> CacheResult<()>
Deletes a cached value and records delete failures in shared stats.
Sourcepub async fn get_or_load_json<T, F, Fut>(
&self,
key: &CacheKey,
loader: F,
) -> CacheResult<Option<T>>where
T: DeserializeOwned + Serialize + Send + Sync,
F: FnOnce() -> Fut + Send,
Fut: Future<Output = CacheResult<Option<T>>> + Send,
pub async fn get_or_load_json<T, F, Fut>(
&self,
key: &CacheKey,
loader: F,
) -> CacheResult<Option<T>>where
T: DeserializeOwned + Serialize + Send + Sync,
F: FnOnce() -> Fut + Send,
Fut: Future<Output = CacheResult<Option<T>>> + Send,
Reads JSON from cache or loads it once for concurrent misses.