Structs
- Prepared
LogWriter - Prepared writer information.
- Rolling
File Config - Rolling file configuration.
- Runtime
Rolling File Writer - Shared writer that rotates the active file while the process is running.
Enums
- LogWriter
Config - Log writer destination.
- Rotation
Policy - Rolling policy for file-backed logs.
Functions
- validate_
writer - Validates the writer and prepares file paths when necessary.