pub struct ServiceGroupConfig {
pub shutdown_timeout: Duration,
pub stop_on_first_error: bool,
}Expand description
Service group runtime controls.
Fields
shutdown_timeout: DurationMaximum time allowed for service stop hooks and task shutdown.
stop_on_first_error: boolWhether the group cancels all services after the first service error.