RequestContext

Struct RequestContext 

pub struct RequestContext { /* private fields */ }
Low-cardinality request context shared by REST/RPC Tower layers.

Implementations

Source

impl RequestContext

pub fn new( service: impl Into<String>, transport: &'static str, route: impl Into<String>, method: impl Into<String>, ) -> Self

Creates a context from explicit low-cardinality parts.

pub fn from_http_headers( service: Option<&str>, method: impl Into<String>, route: Option<&str>, headers: &HeaderMap, ) -> Self

Builds an HTTP request context from headers and a route pattern.

pub fn from_tonic_metadata( service: impl Into<String>, method: impl Into<String>, metadata: &MetadataMap, ) -> Self

Builds a gRPC request context from tonic metadata and a method pattern.

pub fn with_request_id(self, request_id: impl Into<String>) -> Self

Sets a request id.

pub fn with_traceparent(self, traceparent: impl Into<String>) -> Self

Sets a W3C traceparent and derives trace/span ids when valid.

pub fn service(&self) -> &str

Returns the service name.

pub fn transport(&self) -> &'static str

Returns the transport name.

pub fn route(&self) -> &str

Returns the route or RPC method pattern.

pub fn method(&self) -> &str

Returns the HTTP or RPC method.

pub fn request_id(&self) -> Option<&str>

Returns the request id.

pub fn traceparent(&self) -> Option<&str>

Returns the traceparent.

pub fn trace_id(&self) -> Option<&str>

Returns the trace id.

pub fn span_id(&self) -> Option<&str>

Returns the span id.

pub fn inject_http_headers( &self, headers: &mut HeaderMap, ) -> Result<(), InvalidHeaderValue>

Inserts context values into HTTP headers when they are missing.

pub fn inject_tonic_metadata( &self, metadata: &mut MetadataMap, ) -> Result<(), InvalidMetadataValue>

Inserts context values into tonic metadata when they are missing.

pub fn insert_tonic_extensions<T>(&self, request: &mut Request<T>)

Inserts context values into request extensions for downstream layers.