CorrelationContext

Struct CorrelationContext 

pub struct CorrelationContext { /* private fields */ }
Stable, low-cardinality correlation fields for logs, spans, and metrics.

Implementations

Source

impl CorrelationContext

pub fn from_http_headers( service: Option<&str>, method: impl Into<String>, route: Option<&str>, headers: &HeaderMap, ) -> Self

Builds HTTP correlation from headers and a route pattern.

route must be a framework route pattern such as /users/:id; raw paths are intentionally not accepted to avoid high-cardinality logs.

pub fn from_rpc_metadata( service: impl Into<String>, method: impl Into<String>, metadata: &MetadataMap, ) -> Self

Builds gRPC correlation from tonic metadata and an RPC method pattern.

pub fn from_rpc_parts( service: impl Into<String>, method: impl Into<String>, request_id: Option<&str>, traceparent: Option<&str>, ) -> Self

Builds correlation from explicit RPC request and trace context.

pub fn new( service: impl Into<String>, transport: &'static str, route: impl Into<String>, method: impl Into<String>, ) -> Self

Creates a low-cardinality context from explicit parts.

pub fn with_status(self, status: impl Into<String>) -> Self

Sets status or code.

pub fn service(&self) -> &str

Returns the service name.

pub fn transport(&self) -> &'static str

Returns the transport name.

pub fn route(&self) -> &str

Returns the route pattern or unknown.

pub fn method(&self) -> &str

Returns the HTTP or RPC method.

pub fn traceparent(&self) -> Option<&str>

Returns the traceparent value when one is available.

pub fn request_id(&self) -> Option<&str>

Returns the request id when one is available.

pub fn trace_id(&self) -> Option<&str>

Returns the trace id when one is available.

pub fn span_id(&self) -> Option<&str>

Returns the span id when one is available.

pub fn into_log_fields(self) -> LogFields

Converts the context into stable logging fields.

pub fn as_pairs(&self) -> Vec<(String, String)>

Returns all populated fields as key/value pairs.