pub struct RollingWindow { /* private fields */ }Expand description
Fixed-bucket sliding window for resilience decisions.
Implementations
Sourceimpl RollingWindow
impl RollingWindow
Sourcepub fn new(config: WindowConfig) -> Self
pub fn new(config: WindowConfig) -> Self
Creates a rolling window from configuration.
Sourcepub fn record(&mut self, outcome: WindowOutcome)
pub fn record(&mut self, outcome: WindowOutcome)
Records an outcome at the current instant.
Sourcepub fn record_with_latency(&mut self, outcome: WindowOutcome, latency: Duration)
pub fn record_with_latency(&mut self, outcome: WindowOutcome, latency: Duration)
Records an outcome with a latency sample at the current instant.
Sourcepub fn snapshot(&self) -> WindowSnapshot
pub fn snapshot(&self) -> WindowSnapshot
Returns an aggregate over all live buckets.
Sourcepub fn max_successes_per_bucket(&self) -> u64
pub fn max_successes_per_bucket(&self) -> u64
Returns the maximum successful operations observed in one live bucket.
Sourcepub fn min_average_latency(&self) -> Option<Duration>
pub fn min_average_latency(&self) -> Option<Duration>
Returns the minimum average latency observed in one live bucket.