pub struct RestServiceConfig {
pub name: String,
pub mode: String,
pub server: RestServerSection,
pub log: LogSection,
pub auth: Option<RestAuthSection>,
pub middlewares: RestMiddlewaresSection,
pub rpc_clients: BTreeMap<String, RpcClientSection>,
pub database: Option<DatabaseSection>,
}Expand description
REST service configuration loaded by generated services.
Fields
name: StringService name.
mode: StringDeployment mode.
server: RestServerSectionServer listener and request limits.
log: LogSectionLogging configuration.
auth: Option<RestAuthSection>Optional JWT auth configuration.
middlewares: RestMiddlewaresSectionMiddleware toggles.
rpc_clients: BTreeMap<String, RpcClientSection>Outbound RPC clients used by this REST service.
database: Option<DatabaseSection>Optional database used by model repositories.
Implementations
Sourceimpl RestServiceConfig
impl RestServiceConfig
Sourcepub fn load(basename: &str, env_prefix: &str) -> Result<Self, ConfigError>
pub fn load(basename: &str, env_prefix: &str) -> Result<Self, ConfigError>
Loads REST service configuration from basename and env vars with env_prefix.
Sourcepub fn addr(&self) -> CoreResult<SocketAddr>
pub fn addr(&self) -> CoreResult<SocketAddr>
Returns the listening address.
Sourcepub fn log_config(&self) -> LogConfig
pub fn log_config(&self) -> LogConfig
Converts to runtime logging config.
Sourcepub fn rest_config(&self) -> RestConfig
pub fn rest_config(&self) -> RestConfig
Converts to runtime REST config.
Sourcepub fn validate_features(&self) -> Vec<ConfigFeatureWarning>
pub fn validate_features(&self) -> Vec<ConfigFeatureWarning>
Returns warnings for config options that are unavailable in this Cargo feature build.
Sourcepub fn jwt_expires(&self) -> Option<u64>
pub fn jwt_expires(&self) -> Option<u64>
Returns configured JWT expiration in seconds, with JWT_AUTH_EXPIRES precedence.
Sourcepub fn rpc_client(&self, name: &str) -> CoreResult<&RpcClientSection>
pub fn rpc_client(&self, name: &str) -> CoreResult<&RpcClientSection>
Returns one outbound RPC client dependency by logical name.
Sourcepub fn rpc_client_config(&self, name: &str) -> CoreResult<RpcClientConfig>
pub fn rpc_client_config(&self, name: &str) -> CoreResult<RpcClientConfig>
Converts one outbound RPC client dependency to runtime RPC config.
Sourcepub fn database_config(&self) -> Option<DatabaseConfig>
pub fn database_config(&self) -> Option<DatabaseConfig>
Converts the optional database dependency to runtime database config.