pub struct RpcClientBuilder { /* private fields */ }Expand description
Tower-first RPC client builder.
Implementations
Sourceimpl RpcClientBuilder
impl RpcClientBuilder
Sourcepub fn new(config: RpcClientConfig) -> Self
pub fn new(config: RpcClientConfig) -> Self
Creates a builder from client configuration.
Sourcepub fn config(&self) -> &RpcClientConfig
pub fn config(&self) -> &RpcClientConfig
Returns the builder configuration.
Sourcepub async fn connect(&self) -> Result<Channel, Error>
pub async fn connect(&self) -> Result<Channel, Error>
Connects a tonic channel using the configured endpoint and timeouts.
Sourcepub fn inject_request_context<T>(
&self,
context: &RequestContext,
request: &mut Request<T>,
) -> Result<(), InvalidMetadataValue>
pub fn inject_request_context<T>( &self, context: &RequestContext, request: &mut Request<T>, ) -> Result<(), InvalidMetadataValue>
Injects request context into an outgoing tonic request.
Sourcepub async fn scope_request_id<T>(
&self,
request_id: impl Into<String>,
future: impl Future<Output = T>,
) -> T
pub async fn scope_request_id<T>( &self, request_id: impl Into<String>, future: impl Future<Output = T>, ) -> T
Runs a future with the provided request id available to outgoing RPC calls.