RpcResilienceConfig

Struct RpcResilienceConfig 

pub struct RpcResilienceConfig {
Show 16 fields pub breaker_enabled: bool, pub breaker_failure_threshold: u32, pub breaker_reset_timeout: Duration, pub breaker_sre_enabled: bool, pub breaker_sre_k_millis: u32, pub breaker_sre_protection: u64, pub max_concurrency: Option<usize>, pub request_timeout: Duration, pub shedding_enabled: bool, pub shedding_max_in_flight: Option<usize>, pub shedding_min_request_count: u64, pub shedding_max_latency: Duration, pub shedding_cpu_threshold_millis: u32, pub shedding_cool_off: Duration, pub shedding_window_buckets: usize, pub shedding_window_bucket_duration: Duration,
}
RPC resilience configuration shared by future tonic layers.

Fields

breaker_enabled: bool

Whether RPC breaker integration should be enabled by adapters.

breaker_failure_threshold: u32

Consecutive failures that open an RPC breaker.

breaker_reset_timeout: Duration

Time before an open RPC breaker allows a half-open trial call.

breaker_sre_enabled: bool

Whether the RPC breaker uses Google SRE style adaptive rejection.

breaker_sre_k_millis: u32

SRE breaker multiplier in millis. 1500 means k = 1.5.

breaker_sre_protection: u64

Minimum total samples before SRE breaker rejection can start.

max_concurrency: Option<usize>

Optional maximum number of in-flight RPC calls.

request_timeout: Duration

Per-call timeout used by generated service adapters.

shedding_enabled: bool

Whether adaptive RPC shedding is enabled.

shedding_max_in_flight: Option<usize>

Maximum in-flight calls used by the adaptive shedder.

shedding_min_request_count: u64

Minimum samples before latency-based shedding can reject.

shedding_max_latency: Duration

Average latency threshold used by adaptive shedding.

shedding_cpu_threshold_millis: u32

CPU usage threshold used by adaptive shedding, where 1000 means 100%.

shedding_cool_off: Duration

Cool-off duration after a recent adaptive shedder drop.

shedding_window_buckets: usize

Number of buckets used by adaptive shedder rolling windows.

shedding_window_bucket_duration: Duration

Duration represented by each adaptive shedder bucket.

Implementations

Source

impl RpcResilienceConfig

pub fn production_defaults() -> Self

Returns a production-oriented resilience profile for unary RPC calls.

pub fn go_zero_defaults() -> Self

👎Deprecated:

use production_defaults instead

Returns a production-oriented resilience profile for unary RPC calls.