pub fn trace_context_interceptor() -> impl InterceptorExpand description
Builds an interceptor that injects the current traceparent when available.
pub fn trace_context_interceptor() -> impl InterceptorBuilds an interceptor that injects the current traceparent when available.