RpcServiceConfig

Struct RpcServiceConfig 

pub struct RpcServiceConfig {
    pub name: String,
    pub mode: String,
    pub server: RpcServerSection,
    pub log: LogSection,
    pub middlewares: RpcMiddlewaresSection,
    pub rpc_clients: BTreeMap<String, RpcClientSection>,
    pub database: Option<DatabaseSection>,
}
RPC service configuration loaded by generated services.

Fields

name: String

Service name.

mode: String

Deployment mode.

server: RpcServerSection

Server listener and timeout settings.

log: LogSection

Logging configuration.

middlewares: RpcMiddlewaresSection

Middleware toggles.

rpc_clients: BTreeMap<String, RpcClientSection>

Outbound RPC clients used by this RPC service.

database: Option<DatabaseSection>

Optional database used by model repositories.

Implementations

Source

impl RpcServiceConfig

pub fn load(basename: &str, env_prefix: &str) -> Result<Self, ConfigError>

Loads RPC service configuration from basename and env vars with env_prefix.

pub fn addr(&self) -> CoreResult<SocketAddr>

Returns the listening address.

pub fn log_config(&self) -> LogConfig

Converts to runtime logging config.

pub fn validate_features(&self) -> Vec<ConfigFeatureWarning>

Returns warnings for config options that are unavailable in this Cargo feature build.

pub fn rpc_server_config(&self) -> CoreResult<RpcServerConfig>

Converts to runtime RPC server config.

pub fn rpc_client(&self, name: &str) -> CoreResult<&RpcClientSection>

Returns one outbound RPC client dependency by logical name.

pub fn rpc_client_config(&self, name: &str) -> CoreResult<RpcClientConfig>

Converts one outbound RPC client dependency to runtime RPC config.

pub fn database_config(&self) -> Option<DatabaseConfig>

Converts the optional database dependency to runtime database config.