Module writer

Module writer 

Structs

PreparedLogWriter
Prepared writer information.
RollingFileConfig
Rolling file configuration.
RuntimeRollingFileWriter
Shared writer that rotates the active file while the process is running.

Enums

LogWriterConfig
Log writer destination.
RotationPolicy
Rolling policy for file-backed logs.

Functions

validate_writer
Validates the writer and prepares file paths when necessary.