pub struct ServiceGroup { /* private fields */ }Expand description
A group of async services that start together and stop together.
Services are started concurrently. Like go-zero’s service group, startup order must not be relied on. When a process shutdown signal, explicit handle stop, or service error occurs, the group broadcasts a shutdown token, runs stop hooks, waits for tasks and returns aggregated errors if any.
Implementations
Sourceimpl ServiceGroup
impl ServiceGroup
Sourcepub fn with_config(config: ServiceGroupConfig) -> Self
pub fn with_config(config: ServiceGroupConfig) -> Self
Creates an empty service group with custom controls.
Sourcepub fn add<S>(&mut self, service: S) -> &mut Selfwhere
S: Service,
pub fn add<S>(&mut self, service: S) -> &mut Selfwhere
S: Service,
Adds a service to the group.
Sourcepub fn add_arc<S>(&mut self, service: Arc<S>) -> &mut Selfwhere
S: Service,
pub fn add_arc<S>(&mut self, service: Arc<S>) -> &mut Selfwhere
S: Service,
Adds an already shared service to the group.
Sourcepub fn add_fn<F, Fut>(&mut self, name: impl Into<String>, start: F) -> &mut Selfwhere
F: Fn(ShutdownToken) -> Fut + Send + Sync + 'static,
Fut: Future<Output = CoreResult<()>> + Send + 'static,
pub fn add_fn<F, Fut>(&mut self, name: impl Into<String>, start: F) -> &mut Selfwhere
F: Fn(ShutdownToken) -> Fut + Send + Sync + 'static,
Fut: Future<Output = CoreResult<()>> + Send + 'static,
Adds a service backed by an async start function.
Sourcepub fn handle(&self) -> ServiceGroupHandle
pub fn handle(&self) -> ServiceGroupHandle
Returns a handle that can stop the group while it is running.
Sourcepub async fn start(self) -> CoreResult<()>
pub async fn start(self) -> CoreResult<()>
Starts all services and waits for Ctrl-C or explicit stop.
Sourcepub async fn start_with_shutdown<F>(self, shutdown: F) -> CoreResult<()>
pub async fn start_with_shutdown<F>(self, shutdown: F) -> CoreResult<()>
Starts all services and waits for the supplied shutdown future.