ServiceGroupConfig

Struct ServiceGroupConfig 

pub struct ServiceGroupConfig {
    pub shutdown_timeout: Duration,
    pub stop_on_first_error: bool,
}
Service group runtime controls.

Fields

shutdown_timeout: Duration

Maximum time allowed for service stop hooks and task shutdown.

stop_on_first_error: bool

Whether the group cancels all services after the first service error.