pub struct RequestContext { /* private fields */ }Expand description
Low-cardinality request context shared by REST/RPC Tower layers.
Implementations
Sourceimpl RequestContext
impl RequestContext
Sourcepub fn new(
service: impl Into<String>,
transport: &'static str,
route: impl Into<String>,
method: impl Into<String>,
) -> Self
pub fn new( service: impl Into<String>, transport: &'static str, route: impl Into<String>, method: impl Into<String>, ) -> Self
Creates a context from explicit low-cardinality parts.
Sourcepub fn from_http_headers(
service: Option<&str>,
method: impl Into<String>,
route: Option<&str>,
headers: &HeaderMap,
) -> Self
pub fn from_http_headers( service: Option<&str>, method: impl Into<String>, route: Option<&str>, headers: &HeaderMap, ) -> Self
Builds an HTTP request context from headers and a route pattern.
Sourcepub fn from_tonic_metadata(
service: impl Into<String>,
method: impl Into<String>,
metadata: &MetadataMap,
) -> Self
pub fn from_tonic_metadata( service: impl Into<String>, method: impl Into<String>, metadata: &MetadataMap, ) -> Self
Builds a gRPC request context from tonic metadata and a method pattern.
Sourcepub fn with_request_id(self, request_id: impl Into<String>) -> Self
pub fn with_request_id(self, request_id: impl Into<String>) -> Self
Sets a request id.
Sourcepub fn with_traceparent(self, traceparent: impl Into<String>) -> Self
pub fn with_traceparent(self, traceparent: impl Into<String>) -> Self
Sets a W3C traceparent and derives trace/span ids when valid.
Sourcepub fn request_id(&self) -> Option<&str>
pub fn request_id(&self) -> Option<&str>
Returns the request id.
Sourcepub fn traceparent(&self) -> Option<&str>
pub fn traceparent(&self) -> Option<&str>
Returns the traceparent.
Sourcepub fn inject_http_headers(
&self,
headers: &mut HeaderMap,
) -> Result<(), InvalidHeaderValue>
pub fn inject_http_headers( &self, headers: &mut HeaderMap, ) -> Result<(), InvalidHeaderValue>
Inserts context values into HTTP headers when they are missing.
Sourcepub fn inject_tonic_metadata(
&self,
metadata: &mut MetadataMap,
) -> Result<(), InvalidMetadataValue>
pub fn inject_tonic_metadata( &self, metadata: &mut MetadataMap, ) -> Result<(), InvalidMetadataValue>
Inserts context values into tonic metadata when they are missing.
Sourcepub fn insert_tonic_extensions<T>(&self, request: &mut Request<T>)
pub fn insert_tonic_extensions<T>(&self, request: &mut Request<T>)
Inserts context values into request extensions for downstream layers.