Structs
- RpcRequest
Id - Request extension key used by
request_id_interceptorto propagate an existing request id from the current task into tonic metadata.
Constants
- REQUEST_
ID_ METADATA - Metadata key propagated by rs-zero RPC clients.
Functions
- deadline_
interceptor - Builds an interceptor that adds
grpc-timeoutmetadata when missing. - request_
id_ interceptor - Builds an interceptor that adds a request id when missing.
- resilience_
rejection_ status - Maps a resilience rejection into a tonic unavailable status.
- rpc_
resilience_ key - Builds a stable resilience key for RPC adapters.
- trace_
context_ interceptor - Builds an interceptor that injects the current traceparent when available.
- with_
rpc_ request_ id - Runs a future with an RPC request id propagation context.