pub struct RpcServiceConfig {
pub name: String,
pub mode: String,
pub server: RpcServerSection,
pub log: LogSection,
pub middlewares: RpcMiddlewaresSection,
pub rpc_clients: BTreeMap<String, RpcClientSection>,
pub database: Option<DatabaseSection>,
}Expand description
RPC service configuration loaded by generated services.
Fields
name: StringService name.
mode: StringDeployment mode.
server: RpcServerSectionServer listener and timeout settings.
log: LogSectionLogging configuration.
middlewares: RpcMiddlewaresSectionMiddleware toggles.
rpc_clients: BTreeMap<String, RpcClientSection>Outbound RPC clients used by this RPC service.
database: Option<DatabaseSection>Optional database used by model repositories.
Implementations
Sourceimpl RpcServiceConfig
impl RpcServiceConfig
Sourcepub fn load(basename: &str, env_prefix: &str) -> Result<Self, ConfigError>
pub fn load(basename: &str, env_prefix: &str) -> Result<Self, ConfigError>
Loads RPC service configuration from basename and env vars with env_prefix.
Sourcepub fn addr(&self) -> CoreResult<SocketAddr>
pub fn addr(&self) -> CoreResult<SocketAddr>
Returns the listening address.
Sourcepub fn log_config(&self) -> LogConfig
pub fn log_config(&self) -> LogConfig
Converts to runtime logging config.
Sourcepub fn validate_features(&self) -> Vec<ConfigFeatureWarning>
pub fn validate_features(&self) -> Vec<ConfigFeatureWarning>
Returns warnings for config options that are unavailable in this Cargo feature build.
Sourcepub fn rpc_server_config(&self) -> CoreResult<RpcServerConfig>
pub fn rpc_server_config(&self) -> CoreResult<RpcServerConfig>
Converts to runtime RPC server config.
Sourcepub fn rpc_client(&self, name: &str) -> CoreResult<&RpcClientSection>
pub fn rpc_client(&self, name: &str) -> CoreResult<&RpcClientSection>
Returns one outbound RPC client dependency by logical name.
Sourcepub fn rpc_client_config(&self, name: &str) -> CoreResult<RpcClientConfig>
pub fn rpc_client_config(&self, name: &str) -> CoreResult<RpcClientConfig>
Converts one outbound RPC client dependency to runtime RPC config.
Sourcepub fn database_config(&self) -> Option<DatabaseConfig>
pub fn database_config(&self) -> Option<DatabaseConfig>
Converts the optional database dependency to runtime database config.